-- Create ESSHWL.ESSSERVERMAPPING table, index and primary key for it.

CREATE TABLE ESSHWL.ESSSERVERMAPPING
  (ESSNAME VARCHAR(250) NOT NULL,
   SERVERLOCATION VARCHAR(250) NOT NULL,
   ESSINFORMATION BLOB(1K) NOT NULL)
IN CSM.CSMTS;

CREATE UNIQUE INDEX ESSHWL.ESSSERVERMAPPING1      
                 ON ESSHWL.ESSSERVERMAPPING         
                 (SERVERLOCATION   ASC, ESSNAME ASC)      
                 USING STOGROUP DSN8G810
                           PRIQTY 3200
       			   SECQTY 3200     
                           ERASE NO      
                 BUFFERPOOL BP0          
                 CLOSE NO;

ALTER TABLE ESSHWL.ESSSERVERMAPPING
  ADD CONSTRAINT PK_ESSSERVERMAPPIN PRIMARY KEY (SERVERLOCATION, ESSNAME);

-- Create tablespace, auxiliary table and primary key for BLOB field ESSINFORMATION

CREATE LOB TABLESPACE ESSINFTS
  IN CSM
  USING STOGROUP DSN8G810       
     PRIQTY 3200
     SECQTY 3200 
  LOG NO;

CREATE AUXILIARY TABLE ESSHWL.ESSSERVERMAPPING_ESSINFORMATION_TAB
  IN CSM.ESSINFTS
  STORES ESSHWL.ESSSERVERMAPPING
  COLUMN ESSINFORMATION;

CREATE UNIQUE INDEX ESSHWL.ESSSERVERMAPPING_ESSINFORMATION_TAB1
  ON ESSHWL.ESSSERVERMAPPING_ESSINFORMATION_TAB
  USING STOGROUP DSN8G810
  PRIQTY 3200
  SECQTY 3200     
  ERASE NO      
  BUFFERPOOL BP0          
  CLOSE NO;


-- Create ESSHWL.SERVERLOCATIONMAPPING table, index and primary key for it.

CREATE TABLE ESSHWL.SERVERLOCATIONMAPPING
  (SERVERLOCATION VARCHAR(250) NOT NULL,
   USERNAME VARCHAR(250),
   PASSWORD VARCHAR(250),
   UNIQUENAME VARCHAR(250),
   NOTIFICATIONPORT INTEGER NOT NULL,
   SERVERTYPE SMALLINT NOT NULL,
   HOSTNAMECLUSTER0 VARCHAR(250),
   PORTNUMBERCLUSTER0 INTEGER NOT NULL,
   USERNAMECLUSTER0 VARCHAR(250),
   PASSWORDCLUSTER0 VARCHAR(250),
   HOSTNAMECLUSTER1 VARCHAR(250),
   PORTNUMBERCLUSTER1 INTEGER NOT NULL,
   USERNAMECLUSTER1 VARCHAR(250),
   PASSWORDCLUSTER1 VARCHAR(250))
IN CSM.CSMTS;

CREATE UNIQUE INDEX ESSHWL.SERVERLOCATIONMAPPING1      
                 ON ESSHWL.SERVERLOCATIONMAPPING         
                 (SERVERLOCATION   ASC)      
                 USING STOGROUP DSN8G810
                           PRIQTY 3200
       			   SECQTY 3200   
                           ERASE NO      
                 BUFFERPOOL BP0          
                 CLOSE NO;

ALTER TABLE ESSHWL.SERVERLOCATIONMAPPING
  ADD CONSTRAINT PK_SERVERLOCATION PRIMARY KEY (SERVERLOCATION);


-- Create ESSHWL.ESSPATH table, index and primary key for it.

CREATE TABLE ESSHWL.ESSPATH
  (PATHID VARCHAR(250) NOT NULL,
   PATHTYPE SMALLINT NOT NULL,
   SERVERLOCATION VARCHAR(250) NOT NULL,
   PATHSTATE SMALLINT NOT NULL,
   SOURCEPORTS BLOB(1K) NOT NULL,
   TARGETPORTS BLOB(1K) NOT NULL,
   AUTOGENERATED BLOB(1K) NOT NULL,
   SOURCEWWNN VARCHAR(250) NOT NULL,
   TARGETWWNN VARCHAR(250) NOT NULL)
IN CSM.CSMTS;

CREATE UNIQUE INDEX ESSHWL.ESSPATH1      
                 ON ESSHWL.ESSPATH         
                 (PATHTYPE   ASC, PATHID ASC, SERVERLOCATION ASC)      
                 USING STOGROUP DSN8G810
                           PRIQTY 3200
       			   SECQTY 3200    
                           ERASE NO      
                 BUFFERPOOL BP0          
                 CLOSE NO;

ALTER TABLE ESSHWL.ESSPATH
  ADD CONSTRAINT PK_ESSPATH PRIMARY KEY (PATHTYPE, PATHID, SERVERLOCATION);

-- Create tablespace, auxiliary table and primary key for BLOB field SOURCEPORTS

CREATE LOB TABLESPACE SRCPORTS
  IN CSM
  USING STOGROUP DSN8G810       
     PRIQTY 3200
     SECQTY 3200 
  LOG NO;

CREATE AUXILIARY TABLE ESSHWL.ESSPATH_SOURCEPORTS_TAB
  IN CSM.SRCPORTS
  STORES ESSHWL.ESSPATH
  COLUMN SOURCEPORTS;

CREATE UNIQUE INDEX ESSHWL.ESSPATH_SOURCEPORTS_TAB1
  ON ESSHWL.ESSPATH_SOURCEPORTS_TAB  
  USING STOGROUP DSN8G810
  PRIQTY 3200
  SECQTY 3200     
  ERASE NO      
  BUFFERPOOL BP0          
  CLOSE NO;

-- Create tablespace, auxiliary table and primary key for BLOB field TARGETPORTS

CREATE LOB TABLESPACE TGTPORTS
  IN CSM
  USING STOGROUP DSN8G810       
     PRIQTY 3200
     SECQTY 3200 
  LOG NO;

CREATE AUXILIARY TABLE ESSHWL.ESSPATH_TARGETPORTS_TAB
  IN CSM.TGTPORTS
  STORES ESSHWL.ESSPATH
  COLUMN TARGETPORTS;

CREATE UNIQUE INDEX ESSHWL.ESSPATH_TARGETPORTS_TAB1
  ON ESSHWL.ESSPATH_TARGETPORTS_TAB
  USING STOGROUP DSN8G810
  PRIQTY 3200
  SECQTY 3200     
  ERASE NO      
  BUFFERPOOL BP0          
  CLOSE NO;

-- Create tablespace, auxiliary table and primary key for BLOB field AUTOGENERATED

CREATE LOB TABLESPACE AUTOGENE
  IN CSM
  USING STOGROUP DSN8G810       
     PRIQTY 3200
     SECQTY 3200 
  LOG NO;

CREATE AUXILIARY TABLE ESSHWL.ESSPATH_AUTOGENERATED_TAB
  IN CSM.AUTOGENE
  STORES ESSHWL.ESSPATH
  COLUMN AUTOGENERATED;

CREATE UNIQUE INDEX ESSHWL.ESSPATH_AUTOGENERATED_TAB1
  ON ESSHWL.ESSPATH_AUTOGENERATED_TAB
  USING STOGROUP DSN8G810
  PRIQTY 3200
  SECQTY 3200     
  ERASE NO      
  BUFFERPOOL BP0          
  CLOSE NO;

-- Create ESSHWL.ASYNCMASTERQUERYMONITOR table, index and primary key for it.

CREATE TABLE ESSHWL.ASYNCMASTERQUERYMONITOR
  (ESSNAME VARCHAR(250) NOT NULL,
   SESSIONNUMBER INTEGER NOT NULL,
   LSSNUMBER INTEGER NOT NULL,
   SSID INTEGER NOT NULL,
   QUERYISRUNNING SMALLINT NOT NULL)
IN CSM.CSMTS;

CREATE UNIQUE INDEX ESSHWL.ASYNCMASTERQUERYMONITOR1      
                 ON ESSHWL.ASYNCMASTERQUERYMONITOR         
                 (ESSNAME   ASC, SESSIONNUMBER ASC, LSSNUMBER ASC)      
                 USING STOGROUP DSN8G810
                           PRIQTY 3200
       			   SECQTY 3200     
                           ERASE NO      
                 BUFFERPOOL BP0          
                 CLOSE NO;

ALTER TABLE ESSHWL.ASYNCMASTERQUERYMONITOR
  ADD CONSTRAINT PK_ASYNCMASTERQUER PRIMARY KEY (ESSNAME, SESSIONNUMBER, LSSNUMBER);


-- Commit changes
COMMIT;