-- Create ESSHWL.ESSSERVERMAPPING table, index and primary key for it.

CREATE TABLE ESSHWL.ESSSERVERMAPPING_bak
  (ESSNAME VARCHAR(250) NOT NULL,
   SERVERLOCATION VARCHAR(250) NOT NULL,
   ESSINFORMATION BLOB(1K) NOT NULL)
IN CSM.CSMTS;

CREATE UNIQUE INDEX ESSHWL.ESSSERVERMAPPING_bak1      
                 ON ESSHWL.ESSSERVERMAPPING_bak         
                 (SERVERLOCATION   ASC, ESSNAME ASC)      
                 USING STOGROUP DSN8G810
                           PRIQTY 3200
       			   SECQTY 3200     
                           ERASE NO      
                 BUFFERPOOL BP0          
                 CLOSE NO;

ALTER TABLE ESSHWL.ESSSERVERMAPPING_bak
  ADD CONSTRAINT PK_ESSSERVERMA_bak PRIMARY KEY (SERVERLOCATION, ESSNAME);

-- Create tablespace, auxiliary table and primary key for BLOB field ESSINFORMATION

CREATE LOB TABLESPACE ESSINFTB
  IN CSM
  USING STOGROUP DSN8G810       
     PRIQTY 3200
     SECQTY 3200 
  LOG NO;

CREATE AUXILIARY TABLE ESSHWL.ESSSERVERMAPPING_ESSINFORMATION_TAB_bak
  IN CSM.ESSINFTB
  STORES ESSHWL.ESSSERVERMAPPING_bak
  COLUMN ESSINFORMATION;

CREATE UNIQUE INDEX ESSHWL.ESSSERVERMAPPING_ESSINFORMATION_TAB_bak1
  ON ESSHWL.ESSSERVERMAPPING_ESSINFORMATION_TAB_bak
  USING STOGROUP DSN8G810
  PRIQTY 3200
  SECQTY 3200     
  ERASE NO      
  BUFFERPOOL BP0          
  CLOSE NO;


-- Create ESSHWL.SERVERLOCATIONMAPPING table, index and primary key for it.

CREATE TABLE ESSHWL.SERVERLOCATIONMAPPING_bak
  (SERVERLOCATION VARCHAR(250) NOT NULL,
   USERNAME VARCHAR(250),
   PASSWORD VARCHAR(250),
   UNIQUENAME VARCHAR(250),
   NOTIFICATIONPORT INTEGER NOT NULL,
   SERVERTYPE SMALLINT NOT NULL,
   HOSTNAMECLUSTER0 VARCHAR(250),
   PORTNUMBERCLUSTER0 INTEGER NOT NULL,
   USERNAMECLUSTER0 VARCHAR(250),
   PASSWORDCLUSTER0 VARCHAR(250),
   HOSTNAMECLUSTER1 VARCHAR(250),
   PORTNUMBERCLUSTER1 INTEGER NOT NULL,
   USERNAMECLUSTER1 VARCHAR(250),
   PASSWORDCLUSTER1 VARCHAR(250))
IN CSM.CSMTS;

CREATE UNIQUE INDEX ESSHWL.SERVERLOCATIONMAPPING_bak1      
                 ON ESSHWL.SERVERLOCATIONMAPPING_bak       
                 (SERVERLOCATION   ASC)      
                 USING STOGROUP DSN8G810
                           PRIQTY 3200
       			   SECQTY 3200   
                           ERASE NO      
                 BUFFERPOOL BP0          
                 CLOSE NO;

ALTER TABLE ESSHWL.SERVERLOCATIONMAPPING_bak
  ADD CONSTRAINT PK_SERVERLOCAT_bak PRIMARY KEY (SERVERLOCATION);


-- Create ESSHWL.ESSPATH table, index and primary key for it.

CREATE TABLE ESSHWL.ESSPATH_bak
  (PATHID VARCHAR(250) NOT NULL,
   PATHTYPE SMALLINT NOT NULL,
   SERVERLOCATION VARCHAR(250) NOT NULL,
   PATHSTATE SMALLINT NOT NULL,
   SOURCEPORTS BLOB(1K) NOT NULL,
   TARGETPORTS BLOB(1K) NOT NULL,
   AUTOGENERATED BLOB(1K) NOT NULL,
   SOURCEWWNN VARCHAR(250) NOT NULL,
   TARGETWWNN VARCHAR(250) NOT NULL)
IN CSM.CSMTS;

CREATE UNIQUE INDEX ESSHWL.ESSPATH_bak1      
                 ON ESSHWL.ESSPATH_bak        
                 (PATHTYPE   ASC, PATHID ASC, SERVERLOCATION ASC)      
                 USING STOGROUP DSN8G810
                           PRIQTY 3200
       			   SECQTY 3200    
                           ERASE NO      
                 BUFFERPOOL BP0          
                 CLOSE NO;

ALTER TABLE ESSHWL.ESSPATH_bak
  ADD CONSTRAINT PK_ESSPATH_bak PRIMARY KEY (PATHTYPE, PATHID, SERVERLOCATION);

-- Create tablespace, auxiliary table and primary key for BLOB field SOURCEPORTS

CREATE LOB TABLESPACE SRCPORTB
  IN CSM
  USING STOGROUP DSN8G810       
     PRIQTY 3200
     SECQTY 3200 
  LOG NO;

CREATE AUXILIARY TABLE ESSHWL.ESSPATH_SOURCEPORTS_TAB_bak
  IN CSM.SRCPORTB
  STORES ESSHWL.ESSPATH_bak
  COLUMN SOURCEPORTS;

CREATE UNIQUE INDEX ESSHWL.ESSPATH_SOURCEPORTS_TAB_bak1
  ON ESSHWL.ESSPATH_SOURCEPORTS_TAB_bak  
  USING STOGROUP DSN8G810
  PRIQTY 3200
  SECQTY 3200     
  ERASE NO      
  BUFFERPOOL BP0          
  CLOSE NO;

-- Create tablespace, auxiliary table and primary key for BLOB field TARGETPORTS

CREATE LOB TABLESPACE TGTPORTB
  IN CSM
  USING STOGROUP DSN8G810       
     PRIQTY 3200
     SECQTY 3200 
  LOG NO;

CREATE AUXILIARY TABLE ESSHWL.ESSPATH_TARGETPORTS_TAB_bak
  IN CSM.TGTPORTB
  STORES ESSHWL.ESSPATH_bak
  COLUMN TARGETPORTS;

CREATE UNIQUE INDEX ESSHWL.ESSPATH_TARGETPORTS_TAB_bak1
  ON ESSHWL.ESSPATH_TARGETPORTS_TAB_bak
  USING STOGROUP DSN8G810
  PRIQTY 3200
  SECQTY 3200     
  ERASE NO      
  BUFFERPOOL BP0          
  CLOSE NO;

-- Create tablespace, auxiliary table and primary key for BLOB field AUTOGENERATED

CREATE LOB TABLESPACE AUTOGENB
  IN CSM
  USING STOGROUP DSN8G810       
     PRIQTY 3200
     SECQTY 3200 
  LOG NO;

CREATE AUXILIARY TABLE ESSHWL.ESSPATH_AUTOGENERATED_TAB_bak
  IN CSM.AUTOGENB
  STORES ESSHWL.ESSPATH_bak
  COLUMN AUTOGENERATED;

CREATE UNIQUE INDEX ESSHWL.ESSPATH_AUTOGENERATED_TAB_bak1
  ON ESSHWL.ESSPATH_AUTOGENERATED_TAB_bak
  USING STOGROUP DSN8G810
  PRIQTY 3200
  SECQTY 3200     
  ERASE NO      
  BUFFERPOOL BP0          
  CLOSE NO;

-- Create ESSHWL.ASYNCMASTERQUERYMONITOR table, index and primary key for it.

CREATE TABLE ESSHWL.ASYNCMASTERQUERYMONITOR_bak
  (ESSNAME VARCHAR(250) NOT NULL,
   SESSIONNUMBER INTEGER NOT NULL,
   LSSNUMBER INTEGER NOT NULL,
   SSID INTEGER NOT NULL,
   QUERYISRUNNING SMALLINT NOT NULL)
IN CSM.CSMTS;

CREATE UNIQUE INDEX ESSHWL.ASYNCMASTERQUERYMONITOR_bak1      
                 ON ESSHWL.ASYNCMASTERQUERYMONITOR_bak         
                 (ESSNAME   ASC, SESSIONNUMBER ASC, LSSNUMBER ASC)      
                 USING STOGROUP DSN8G810
                           PRIQTY 3200
       			   SECQTY 3200     
                           ERASE NO      
                 BUFFERPOOL BP0          
                 CLOSE NO;

ALTER TABLE ESSHWL.ASYNCMASTERQUERYMONITOR_bak
  ADD CONSTRAINT PK_ASYNCMASTER_bak PRIMARY KEY (ESSNAME, SESSIONNUMBER, LSSNUMBER);


-- Commit changes
COMMIT;