-- Create REPMGR.CSMUSER table, index and primary key for it.

CREATE TABLE REPMGR.CSMUSER
  (USERNAME VARCHAR(250) NOT NULL,
   PASSWORD VARCHAR(250) NOT NULL,
   ROLE VARCHAR(250))
IN CSM.CSMTS;

CREATE UNIQUE INDEX REPMGR.CSMUSER1      
                 ON REPMGR.CSMUSER         
                 (USERNAME   ASC)      
                 USING STOGROUP DSN8G810
                           PRIQTY 3200
       			   SECQTY 3200     
                           ERASE NO      
                 BUFFERPOOL BP0          
                 CLOSE NO;

ALTER TABLE REPMGR.CSMUSER
  ADD CONSTRAINT PK_CSMUSER PRIMARY KEY (USERNAME);


-- Create REPMGR.CSMPROPERTIES table, index and primary key for it.

CREATE TABLE REPMGR.CSMPROPERTIES
  (PROP_NAME VARCHAR(250) NOT NULL,
   PROP_VALUE VARCHAR(250) NOT NULL)
IN CSM.CSMTS;

CREATE UNIQUE INDEX REPMGR.CSMPROPERTIES1      
                 ON REPMGR.CSMPROPERTIES         
                 (PROP_NAME   ASC)      
                 USING STOGROUP DSN8G810
                           PRIQTY 3200
       			   SECQTY 3200     
                           ERASE NO      
                 BUFFERPOOL BP0          
                 CLOSE NO;

ALTER TABLE REPMGR.CSMPROPERTIES
  ADD CONSTRAINT PK_CSMPROPERTIES PRIMARY KEY (PROP_NAME);


-- Create REPMGR.DRIVER table, index and primary key for it.

CREATE TABLE REPMGR.DRIVER
  (DRIVERID VARCHAR(250) NOT NULL,
   TYPE1 VARCHAR(250),
   ISSHADOWING SMALLINT NOT NULL,
   CONTROLCLASS VARCHAR(250),
   NUMBEROFPAIRS INTEGER NOT NULL,
   CGINFO BLOB(13000),
   SEQUENCENAME VARCHAR(250),
   SESSIONNAME VARCHAR(250) NOT NULL,
   ISDEFINED SMALLINT NOT NULL,
   TIMESTAMP1 VARCHAR(250),
   INUSE SMALLINT NOT NULL,
   HWCONSISTENCYGROUPNAME VARCHAR(250),
   ISNEW SMALLINT NOT NULL)
IN CSM.CSMTS;

CREATE UNIQUE INDEX REPMGR.DRIVER1      
                 ON REPMGR.DRIVER         
                 (DRIVERID   ASC, SESSIONNAME ASC)      
                 USING STOGROUP DSN8G810
                           PRIQTY 3200
       			   SECQTY 3200     
                           ERASE NO      
                 BUFFERPOOL BP0          
                 CLOSE NO;

ALTER TABLE REPMGR.DRIVER
  ADD CONSTRAINT PK_DRIVER PRIMARY KEY (DRIVERID, SESSIONNAME);

-- Create tablespace, auxiliary table and primary key for BLOB field CGINFO

CREATE LOB TABLESPACE CGINFOTS
  IN CSM
  USING STOGROUP DSN8G810       
     PRIQTY 3200
     SECQTY 3200 
  LOG NO;

CREATE AUXILIARY TABLE REPMGR.DRIVER_CGINFO_TAB
  IN CSM.CGINFOTS
  STORES REPMGR.DRIVER
  COLUMN CGINFO;

CREATE UNIQUE INDEX REPMGR.DRIVER_CGINFO_TAB1
  ON REPMGR.DRIVER_CGINFO_TAB
  USING STOGROUP DSN8G810
  PRIQTY 3200
  SECQTY 3200     
  ERASE NO      
  BUFFERPOOL BP0          
  CLOSE NO;


-- Create REPMGR.PAIR table, index and primary key for it.

CREATE TABLE REPMGR.PAIR
  (SOURCEID VARCHAR(250) NOT NULL,
   TARGETID VARCHAR(250) NOT NULL,
   STATE1 VARCHAR(250),
   DRIVERID VARCHAR(250),
   PENDINGSTATE VARCHAR(250),
   SESSIONNAME VARCHAR(250) NOT NULL,
   SEQUENCENAME VARCHAR(250) NOT NULL, 
   ISNEW SMALLINT NOT NULL,
   TIMESTAMP1 VARCHAR(250),
   ISSHADOWING SMALLINT NOT NULL,
   ISCONSISTENT SMALLINT NOT NULL,
   LASTRESULTTYPE INTEGER NOT NULL,
   LASTRESULTMSGKEY VARCHAR(10),
   LASTRESULTINSERTS BLOB(11000),
   LASTRESULTTIME TIMESTAMP NOT NULL,
   PENDINGREASONCODE INTEGER NOT NULL,
   ISINHWCONSISTENCYGROUP SMALLINT NOT NULL,
   DIRECTION SMALLINT NOT NULL,
   COPYSETID VARCHAR(250))
IN CSM.CSMTS;

CREATE UNIQUE INDEX REPMGR.PAIR1      
                 ON REPMGR.PAIR         
                 (SOURCEID   ASC, TARGETID ASC, SESSIONNAME ASC)      
                 USING STOGROUP DSN8G810
                           PRIQTY 3200
       			   SECQTY 3200     
                           ERASE NO      
                 BUFFERPOOL BP0          
                 CLOSE NO;

ALTER TABLE REPMGR.PAIR
  ADD CONSTRAINT PK_PAIR PRIMARY KEY (SOURCEID, TARGETID, SESSIONNAME);

-- Create tablespace, auxiliary table and primary key for BLOB field LASTRESULTINSERTS

CREATE LOB TABLESPACE LRESINTS
 IN CSM
  USING STOGROUP DSN8G810       
     PRIQTY 3200
     SECQTY 3200 
  LOG NO;

CREATE AUXILIARY TABLE REPMGR.PAIR_LASTRESULTINSERTS_TAB
  IN CSM.LRESINTS
  STORES REPMGR.PAIR
  COLUMN LASTRESULTINSERTS;

CREATE UNIQUE INDEX REPMGR.PAIR_LASTRESULTINSERTS_TAB1
  ON REPMGR.PAIR_LASTRESULTINSERTS_TAB
  USING STOGROUP DSN8G810
  PRIQTY 3200
  SECQTY 3200     
  ERASE NO      
  BUFFERPOOL BP0          
  CLOSE NO;


-- Create REPMGR.SESSION1 table, index and primary key for it.

CREATE TABLE REPMGR.SESSION1
  (SESSIONNAME VARCHAR(250) NOT NULL,
   COPYRULES BLOB(13000),
   CMDBEINGPROCESSED VARCHAR(250),
   STATE VARCHAR(250),
   DESCRIPTION VARCHAR(250),
   PRODUCTIONROLE VARCHAR(250),
   NUMACTIVEDRIVERS INTEGER NOT NULL,
   INUSE SMALLINT NOT NULL,
   INGENERATE VARCHAR(250))
IN CSM.CSMTS;

CREATE UNIQUE INDEX REPMGR.SESSION11      
                 ON REPMGR.SESSION1         
                 (SESSIONNAME   ASC)      
                 USING STOGROUP DSN8G810
                           PRIQTY 3200
       			   SECQTY 3200     
                           ERASE NO      
                 BUFFERPOOL BP0          
                 CLOSE NO;

ALTER TABLE REPMGR.SESSION1
  ADD CONSTRAINT PK_SESSION1 PRIMARY KEY (SESSIONNAME);

-- Create tablespace, auxiliary table and primary key for BLOB field COPYRULES

CREATE LOB TABLESPACE CPYRULTS
 IN CSM
  USING STOGROUP DSN8G810       
     PRIQTY 3200
     SECQTY 3200 
  LOG NO;

CREATE AUXILIARY TABLE REPMGR.SESSION1_COPYRULES_TAB
  IN CSM.CPYRULTS
  STORES REPMGR.SESSION1
  COLUMN COPYRULES;

CREATE UNIQUE INDEX REPMGR.SESSION1_COPYRULES_TAB1
  ON REPMGR.SESSION1_COPYRULES_TAB
  USING STOGROUP DSN8G810
  PRIQTY 3200
  SECQTY 3200     
  ERASE NO      
  BUFFERPOOL BP0          
  CLOSE NO;


-- Create REPMGR.COPYSET table, index and primary key for it.

CREATE TABLE REPMGR.COPYSET
  (COPYSETID VARCHAR(250) NOT NULL,
   CONSISTENCYLEVEL VARCHAR(250),
   SESSIONNAME VARCHAR(250) NOT NULL,
   INGAME SMALLINT NOT NULL,
   ISVALID SMALLINT NOT NULL,
   ISVERIFIED SMALLINT NOT NULL)
IN CSM.CSMTS;

CREATE UNIQUE INDEX REPMGR.COPYSET1      
                 ON REPMGR.COPYSET         
                 (COPYSETID   ASC, SESSIONNAME ASC)      
                 USING STOGROUP DSN8G810
                           PRIQTY 3200
       			   SECQTY 3200     
                           ERASE NO      
                 BUFFERPOOL BP0          
                 CLOSE NO;

ALTER TABLE REPMGR.COPYSET
  ADD CONSTRAINT PK_COPYSET PRIMARY KEY (COPYSETID, SESSIONNAME);


-- Create REPMGR.POINT table, index and primary key for it.

CREATE TABLE REPMGR.POINT
  (POINTID VARCHAR(250) NOT NULL,
   POINTNUMBER INTEGER NOT NULL,
   SESSIONID VARCHAR(250) NOT NULL,
   COPYSETID VARCHAR(250))
IN CSM.CSMTS;

CREATE UNIQUE INDEX REPMGR.POINT1      
                 ON REPMGR.POINT         
                 (POINTID   ASC, SESSIONID ASC)      
                 USING STOGROUP DSN8G810
                           PRIQTY 3200
       			   SECQTY 3200     
                           ERASE NO      
                 BUFFERPOOL BP0          
                 CLOSE NO;

ALTER TABLE REPMGR.POINT
  ADD CONSTRAINT PK_POINT PRIMARY KEY (POINTID, SESSIONID);


-- Create REPMGR.SEQUENCE table, index and primary key for it.

CREATE TABLE REPMGR.SEQUENCE
  (SEQUENCENAME VARCHAR(250) NOT NULL,
   SESSIONNAME VARCHAR(250) NOT NULL,
   DIRECTION SMALLINT NOT NULL)
IN CSM.CSMTS;

CREATE UNIQUE INDEX REPMGR.SEQUENCE1      
                 ON REPMGR.SEQUENCE         
                 (SEQUENCENAME   ASC, SESSIONNAME ASC)      
                 USING STOGROUP DSN8G810
                           PRIQTY 3200
       			   SECQTY 3200    
                           ERASE NO      
                 BUFFERPOOL BP0          
                 CLOSE NO;

ALTER TABLE REPMGR.SEQUENCE
  ADD CONSTRAINT PK_SEQUENCE PRIMARY KEY (SEQUENCENAME, SESSIONNAME);


-- Create REPMGR.HA_STATUS table, index and primary key for it. 

CREATE TABLE REPMGR.HA_STATUS
 (HOSTNAME VARCHAR(250) NOT NULL,
  IPADDRESS VARCHAR(36) NOT NULL,
  ROLE SMALLINT NOT NULL DEFAULT 0,
  STATE SMALLINT NOT NULL DEFAULT 0,
  TIME_STAMP TIMESTAMP NOT NULL)
IN CSM.CSMTS;

CREATE UNIQUE INDEX REPMGR.HA_STATUS1      
                 ON REPMGR.HA_STATUS         
                 (HOSTNAME   ASC, IPADDRESS ASC)      
                 USING STOGROUP DSN8G810
                           PRIQTY 3200
       			   SECQTY 3200     
                           ERASE NO      
                 BUFFERPOOL BP0          
                 CLOSE NO;

ALTER TABLE REPMGR.HA_STATUS
  ADD CONSTRAINT PK_HA_STATUS PRIMARY KEY (HOSTNAME, IPADDRESS);


-- Create REPMGR.SNMP_MGRS table, index and primary key for it. 

CREATE TABLE REPMGR.SNMP_MGRS 
 (MGRNAME VARCHAR (250) NOT NULL, 
  PORT INTEGER NOT NULL WITH DEFAULT 162)
IN CSM.CSMTS;

CREATE UNIQUE INDEX REPMGR.SNMP_MGRS1      
                 ON REPMGR.SNMP_MGRS         
                 (MGRNAME   ASC, PORT ASC)      
                 USING STOGROUP DSN8G810
                           PRIQTY 3200
       			   SECQTY 3200     
                           ERASE NO      
                 BUFFERPOOL BP0          
                 CLOSE NO;
  
ALTER TABLE REPMGR.SNMP_MGRS
  ADD CONSTRAINT PK_SNMP_MGRS PRIMARY KEY ( MGRNAME, PORT);

-- Commit changes;
COMMIT;