-- Create REPMGR.CSMUSER table, index and primary key for it.

CREATE TABLE REPMGR.CSMUSER_bak
  (USERNAME VARCHAR(250) NOT NULL,
   PASSWORD VARCHAR(250) NOT NULL,
   ROLE VARCHAR(250))
IN CSM.CSMTS;

CREATE UNIQUE INDEX REPMGR.CSMUSER_bak1      
                 ON REPMGR.CSMUSER_bak         
                 (USERNAME   ASC)      
                 USING STOGROUP DSN8G810
                           PRIQTY 3200
       			   SECQTY 3200     
                           ERASE NO      
                 BUFFERPOOL BP0          
                 CLOSE NO;

ALTER TABLE REPMGR.CSMUSER_bak
  ADD CONSTRAINT PK_CSMUSER_bak PRIMARY KEY (USERNAME);


-- Create REPMGR.CSMPROPERTIES table, index and primary key for it.

CREATE TABLE REPMGR.CSMPROPERTIES_bak
  (PROP_NAME VARCHAR(250) NOT NULL,
   PROP_VALUE VARCHAR(250) NOT NULL)
IN CSM.CSMTS;

CREATE UNIQUE INDEX REPMGR.CSMPROPERTIES_bak1      
                 ON REPMGR.CSMPROPERTIES_bak         
                 (PROP_NAME   ASC)      
                 USING STOGROUP DSN8G810
                           PRIQTY 3200
       			   SECQTY 3200     
                           ERASE NO      
                 BUFFERPOOL BP0          
                 CLOSE NO;

ALTER TABLE REPMGR.CSMPROPERTIES_bak
  ADD CONSTRAINT PK_CSMPROPER_bak PRIMARY KEY (PROP_NAME);


-- Create REPMGR.DRIVER table, index and primary key for it.

CREATE TABLE REPMGR.DRIVER_bak
  (DRIVERID VARCHAR(250) NOT NULL,
   TYPE1 VARCHAR(250),
   ISSHADOWING SMALLINT NOT NULL,
   CONTROLCLASS VARCHAR(250),
   NUMBEROFPAIRS INTEGER NOT NULL,
   CGINFO BLOB(13000),
   SEQUENCENAME VARCHAR(250),
   SESSIONNAME VARCHAR(250) NOT NULL,
   ISDEFINED SMALLINT NOT NULL,
   TIMESTAMP1 VARCHAR(250),
   INUSE SMALLINT NOT NULL,
   HWCONSISTENCYGROUPNAME VARCHAR(250),
   ISNEW SMALLINT NOT NULL)
IN CSM.CSMTS;

CREATE UNIQUE INDEX REPMGR.DRIVER1_bak      
                 ON REPMGR.DRIVER_bak         
                 (DRIVERID   ASC, SESSIONNAME ASC)      
                 USING STOGROUP DSN8G810
                           PRIQTY 3200
       			   SECQTY 3200     
                           ERASE NO      
                 BUFFERPOOL BP0          
                 CLOSE NO;

ALTER TABLE REPMGR.DRIVER_bak
  ADD CONSTRAINT PK_DRIVER_bak PRIMARY KEY (DRIVERID, SESSIONNAME);

-- Create tablespace, auxiliary table and primary key for BLOB field CGINFO

CREATE LOB TABLESPACE CGINFOTB
  IN CSM
  USING STOGROUP DSN8G810       
     PRIQTY 3200
     SECQTY 3200 
  LOG NO;

CREATE AUXILIARY TABLE REPMGR.DRIVER_CGINFO_TAB_bak
  IN CSM.CGINFOTB
  STORES REPMGR.DRIVER_bak
  COLUMN CGINFO;

CREATE UNIQUE INDEX REPMGR.DRIVER_CGINFO_TAB_bak1
  ON REPMGR.DRIVER_CGINFO_TAB_bak
  USING STOGROUP DSN8G810
  PRIQTY 3200
  SECQTY 3200     
  ERASE NO      
  BUFFERPOOL BP0          
  CLOSE NO;


-- Create REPMGR.PAIR table, index and primary key for it.

CREATE TABLE REPMGR.PAIR_bak
  (SOURCEID VARCHAR(250) NOT NULL,
   TARGETID VARCHAR(250) NOT NULL,
   STATE1 VARCHAR(250),
   DRIVERID VARCHAR(250),
   PENDINGSTATE VARCHAR(250),
   SESSIONNAME VARCHAR(250) NOT NULL,
   SEQUENCENAME VARCHAR(250) NOT NULL, 
   ISNEW SMALLINT NOT NULL,
   TIMESTAMP1 VARCHAR(250),
   ISSHADOWING SMALLINT NOT NULL,
   ISCONSISTENT SMALLINT NOT NULL,
   LASTRESULTTYPE INTEGER NOT NULL,
   LASTRESULTMSGKEY VARCHAR(10),
   LASTRESULTINSERTS BLOB(11000),
   LASTRESULTTIME TIMESTAMP NOT NULL,
   PENDINGREASONCODE INTEGER NOT NULL,
   ISINHWCONSISTENCYGROUP SMALLINT NOT NULL,
   DIRECTION SMALLINT NOT NULL,
   COPYSETID VARCHAR(250))
IN CSM.CSMTS;

CREATE UNIQUE INDEX REPMGR.PAIR_bak1      
                 ON REPMGR.PAIR_bak         
                 (SOURCEID   ASC, TARGETID ASC, SESSIONNAME ASC)      
                 USING STOGROUP DSN8G810
                           PRIQTY 3200
       			   SECQTY 3200     
                           ERASE NO      
                 BUFFERPOOL BP0          
                 CLOSE NO;

ALTER TABLE REPMGR.PAIR_bak
  ADD CONSTRAINT PK_PAIR_bak PRIMARY KEY (SOURCEID, TARGETID, SESSIONNAME);

-- Create tablespace, auxiliary table and primary key for BLOB field LASTRESULTINSERTS

CREATE LOB TABLESPACE LRESINTB
 IN CSM
  USING STOGROUP DSN8G810       
     PRIQTY 3200
     SECQTY 3200 
  LOG NO;

CREATE AUXILIARY TABLE REPMGR.PAIR_LASTRESULTINSERTS_TAB_bak
  IN CSM.LRESINTB
  STORES REPMGR.PAIR_bak
  COLUMN LASTRESULTINSERTS;

CREATE UNIQUE INDEX REPMGR.PAIR_LASTRESULTINSERTS_TAB_bak1
  ON REPMGR.PAIR_LASTRESULTINSERTS_TAB_bak
  USING STOGROUP DSN8G810
  PRIQTY 3200
  SECQTY 3200     
  ERASE NO      
  BUFFERPOOL BP0          
  CLOSE NO;


-- Create REPMGR.SESSION1 table, index and primary key for it.

CREATE TABLE REPMGR.SESSION1_bak
  (SESSIONNAME VARCHAR(250) NOT NULL,
   COPYRULES BLOB(13000),
   CMDBEINGPROCESSED VARCHAR(250),
   STATE VARCHAR(250),
   DESCRIPTION VARCHAR(250),
   PRODUCTIONROLE VARCHAR(250),
   NUMACTIVEDRIVERS INTEGER NOT NULL,
   INUSE SMALLINT NOT NULL,
   INGENERATE VARCHAR(250))
IN CSM.CSMTS;

CREATE UNIQUE INDEX REPMGR.SESSION1_bak1      
                 ON REPMGR.SESSION1_bak         
                 (SESSIONNAME   ASC)      
                 USING STOGROUP DSN8G810
                           PRIQTY 3200
       			   SECQTY 3200     
                           ERASE NO      
                 BUFFERPOOL BP0          
                 CLOSE NO;

ALTER TABLE REPMGR.SESSION1_bak
  ADD CONSTRAINT PK_SESSION1_bak PRIMARY KEY (SESSIONNAME);

-- Create tablespace, auxiliary table and primary key for BLOB field COPYRULES

CREATE LOB TABLESPACE CPYRULTB
 IN CSM
  USING STOGROUP DSN8G810       
     PRIQTY 3200
     SECQTY 3200 
  LOG NO;

CREATE AUXILIARY TABLE REPMGR.SESSION1_COPYRULES_TAB_bak
  IN CSM.CPYRULTB
  STORES REPMGR.SESSION1_bak
  COLUMN COPYRULES;

CREATE UNIQUE INDEX REPMGR.SESSION1_COPYRULES_TAB_bak1
  ON REPMGR.SESSION1_COPYRULES_TAB_bak
  USING STOGROUP DSN8G810
  PRIQTY 3200
  SECQTY 3200     
  ERASE NO      
  BUFFERPOOL BP0          
  CLOSE NO;


-- Create REPMGR.COPYSET table, index and primary key for it.

CREATE TABLE REPMGR.COPYSET_bak
  (COPYSETID VARCHAR(250) NOT NULL,
   CONSISTENCYLEVEL VARCHAR(250),
   SESSIONNAME VARCHAR(250) NOT NULL,
   INGAME SMALLINT NOT NULL,
   ISVALID SMALLINT NOT NULL,
   ISVERIFIED SMALLINT NOT NULL)
IN CSM.CSMTS;

CREATE UNIQUE INDEX REPMGR.COPYSET_bak1      
                 ON REPMGR.COPYSET_bak         
                 (COPYSETID   ASC, SESSIONNAME ASC)      
                 USING STOGROUP DSN8G810
                           PRIQTY 3200
       			   SECQTY 3200     
                           ERASE NO      
                 BUFFERPOOL BP0          
                 CLOSE NO;

ALTER TABLE REPMGR.COPYSET_bak
  ADD CONSTRAINT PK_COPYSET_bak PRIMARY KEY (COPYSETID, SESSIONNAME);


-- Create REPMGR.POINT table, index and primary key for it.

CREATE TABLE REPMGR.POINT_bak
  (POINTID VARCHAR(250) NOT NULL,
   POINTNUMBER INTEGER NOT NULL,
   SESSIONID VARCHAR(250) NOT NULL,
   COPYSETID VARCHAR(250))
IN CSM.CSMTS;

CREATE UNIQUE INDEX REPMGR.POINT1_bak      
                 ON REPMGR.POINT_bak         
                 (POINTID   ASC, SESSIONID ASC)      
                 USING STOGROUP DSN8G810
                           PRIQTY 3200
       			   SECQTY 3200     
                           ERASE NO      
                 BUFFERPOOL BP0          
                 CLOSE NO;

ALTER TABLE REPMGR.POINT_bak
  ADD CONSTRAINT PK_POINT_bak PRIMARY KEY (POINTID, SESSIONID);


-- Create REPMGR.SEQUENCE table, index and primary key for it.

CREATE TABLE REPMGR.SEQUENCE_bak
  (SEQUENCENAME VARCHAR(250) NOT NULL,
   SESSIONNAME VARCHAR(250) NOT NULL,
   DIRECTION SMALLINT NOT NULL)
IN CSM.CSMTS;

CREATE UNIQUE INDEX REPMGR.SEQUENCE1_bak      
                 ON REPMGR.SEQUENCE_bak         
                 (SEQUENCENAME   ASC, SESSIONNAME ASC)      
                 USING STOGROUP DSN8G810
                           PRIQTY 3200
       			   SECQTY 3200    
                           ERASE NO      
                 BUFFERPOOL BP0          
                 CLOSE NO;

ALTER TABLE REPMGR.SEQUENCE_bak
  ADD CONSTRAINT PK_SEQUENC_bak PRIMARY KEY (SEQUENCENAME, SESSIONNAME);


-- Create REPMGR.HA_STATUS table, index and primary key for it. 

CREATE TABLE REPMGR.HA_STATUS_bak
 (HOSTNAME VARCHAR(250) NOT NULL,
  IPADDRESS VARCHAR(36) NOT NULL,
  ROLE SMALLINT NOT NULL DEFAULT 0,
  STATE SMALLINT NOT NULL DEFAULT 0,
  TIME_STAMP TIMESTAMP NOT NULL)
IN CSM.CSMTS;

CREATE UNIQUE INDEX REPMGR.HA_STATUS1_bak      
                 ON REPMGR.HA_STATUS_bak         
                 (HOSTNAME   ASC, IPADDRESS ASC)      
                 USING STOGROUP DSN8G810
                           PRIQTY 3200
       			   SECQTY 3200     
                           ERASE NO      
                 BUFFERPOOL BP0          
                 CLOSE NO;

ALTER TABLE REPMGR.HA_STATUS_bak
  ADD CONSTRAINT PK_HA_STATU_bak PRIMARY KEY (HOSTNAME, IPADDRESS);


-- Create REPMGR.SNMP_MGRS table, index and primary key for it. 

CREATE TABLE REPMGR.SNMP_MGRS_bak 
 (MGRNAME VARCHAR (250) NOT NULL, 
  PORT INTEGER NOT NULL WITH DEFAULT 162)
IN CSM.CSMTS;

CREATE UNIQUE INDEX REPMGR.SNMP_MGRS1_bak      
                 ON REPMGR.SNMP_MGRS_bak         
                 (MGRNAME   ASC, PORT ASC)      
                 USING STOGROUP DSN8G810
                           PRIQTY 3200
       			   SECQTY 3200     
                           ERASE NO      
                 BUFFERPOOL BP0          
                 CLOSE NO;
  
ALTER TABLE REPMGR.SNMP_MGRS_bak
  ADD CONSTRAINT PK_SNMP_MGR_bak PRIMARY KEY ( MGRNAME, PORT);

-- Commit changes;
COMMIT;